from qradarbase import QRadarAPI, QRadarError, QRadarSetupError

# Replace object with \BaseAPI
class QRadar(QRadarAPI):
    def __init__(self, host, SEC_token='', port=443, ssl_verify=False, scheme='https'):
        if not SEC_token:
            raise QRadarSetupError("Usage: pyQRadar.QRadar(\"ip\",\"token\")") 

        self.header = {
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Version': '7.0',
            'SEC': '%s' % SEC_token
        }

        QRadarAPI.__init__(self, host, port, ssl_verify, scheme)

    def login(self):
        # Attempting to remove the first part of this based on the API used
        # Might be a bad idea as you need admin for this one.
        return self.get('servers', headers=self.header)



import json
import requests

class QRadarSetupError(Exception):
    def __init__(self, msg):
        self.msg = msg

    def __str__(self):
        return repr('%s' % self.msg)

class QRadarError(Exception):
    def __init__(self, code, msg):
        self.code = code
        self.msg = msg

    def __str__(self):
        return repr('[%s]: %s' % (self.code, self.msg))

class QRadarAPI(object):
    def __init__(self, host, port=443, ssl_verify=False, scheme='https'):
        self.session = requests.Session()
        self.scheme = scheme
        self.host = host
        self.port = port
        self.ssl_verify = ssl_verify

    def _url_builder(self, path, id=""):
        url = "%s://%s:%s/api/%s" % (self.scheme, self.host, self.port, path)

		# Might be legacy
        if id:
            try:
                url += "/%s" % int(id)
            except ValueError:
                raise QRadarError("405", "\"Id\" needs to be an integer.")

        return url

    def _kwarg_builder(self, **kwargs):
        if "headers" not in kwargs:
            kwargs["headers"] = {}

        kwargs['verify'] = self.ssl_verify

		# Add json data recognition for json= or data=

        if not self.ssl_verify:
            requests.packages.urllib3.disable_warnings(\
                requests.packages.urllib3.exceptions.InsecureRequestWarning)

        return kwargs

    def _resp_error_check(self, response):
        try:
            d = response.json()

            if response.status_code != 200:
                raise QRadarError(response.status_code, d["message"])
        except ValueError:
            pass

        return response

    def get(self, path, **kwargs):
        response = self.session.get(self._url_builder(path),\
            **self._kwarg_builder(**kwargs))

        return self._resp_error_check(response)

    # Check for data.
    def post(self, path, **kwargs):
        response = self.session.post(self._url_builder(path),\
            **self._kwarg_builder(**kwargs))

        return self._resp_error_check(response)

    def put(self, path, **kwargs):
        response = self.session.put(self._url_builder(path),\
            **self._kwarg_builder(**kwargs))

        return self._resp_error_check(response)

    def delete(self, path, **kwargs):
        response = self.session.delete(self._url_builder(path),\
            **self._kwarg_builder(**kwargs))

        return self._resp_error_check(response)

    def head(self, path, **kwargs):
        response = self.session.head(self._url_builder(path),\
            **self._kwarg_builder(**kwargs))

        return self._resp_error_check(response)



from setuptools import setup
import os

setup(
    name="pyQRadar",
    version='0.1.0',
    description="QRadar API Library",
    author='@Frikkylikeme',
    author_email="fredrik_9490@hotmail.com",
    url="https://github.com/frikky/pyQRadar",
    packages=["qradar",],
    install_requires=["requests",]
)
